@@ -20,7 +20,6 @@
 
 
 #include "gcommon.h"
-#include "misc/misc.h"
 #ifdef G_OS_WIN32
 # include <tchar.h>
 # include <windows.h>
@@ -74,6 +73,7 @@ extern gchar *genre[256][256];          /* ja:ジャンル */
 extern gint genres;                     /* ja:ジャンルの数 */
 extern gint def_gnum;                   /* ja:デフォルトのジャンル */
 extern gint def_width, def_height;      /* ja:デフォルトのウインドウのサイズ */
+extern gint license;                    /* ja:ライセンス */
 extern gint playlist;                   /* ja:プレイリスト */
 extern GObject *history;                /* ja:ファイルの履歴 */
 extern GdkAtom atom_targets;            /* ja:ターゲット */
@@ -84,9 +84,6 @@ extern GtkWidget *mdi;                  /* en:MDI */
 #ifdef G_OS_WIN32
 extern UINT uFormat;                    /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
-extern MiscCreateMenuEntry menu_entries[];
-extern MiscCreateMenuEntry popup_entries[];
-extern MiscCreateToolbarEntry toolbar_entries[];
 
 
 G_END_DECLS
